using System;
using System.Data;
using System.Data.SqlClient;
using System.Collections;
using System.Configuration;

namespace DBPrac2
{
	/// <summary>
	/// Summary description for EmpDB.
	/// </summary>
	public class EmpDB
	{
		string connStr;

		public EmpDB()
		{
			connStr  = ConfigurationSettings.AppSettings["connStr"];
		}

		public int InsertEmployee(EmpDetails emp)
		{
			SqlConnection conn = new SqlConnection(connStr);
			SqlCommand cmd = conn.CreateCommand();
			cmd.CommandType = CommandType.StoredProcedure;
			cmd.CommandText = "procInsertEmployee";
			
			cmd.Parameters.Add(new SqlParameter("@EmployeeId",SqlDbType.Int));
			cmd.Parameters["@EmployeeId"].Direction = ParameterDirection.Output;

			cmd.Parameters.Add(new SqlParameter("@FirstName",SqlDbType.NVarChar,20));
			cmd.Parameters["@FirstName"].Value = emp.FirstName;

			cmd.Parameters.Add(new SqlParameter("@LastName",SqlDbType.NVarChar,20));
			cmd.Parameters["@LastName"].Value = emp.LastName;

			try
			{
				conn.Open();
				int RecordsAffected = cmd.ExecuteNonQuery();
				int EmpId;
				if(RecordsAffected != 0)
					EmpId = (int)cmd.Parameters["@EmployeeId"].Value;
				else
					EmpId = -1;
				conn.Close();
				return EmpId;
			}
			catch(SqlException ex)
			{
				throw new ApplicationException("Data Error");
			}
			finally
			{
				conn.Close();
			}
		}

		public int UpdateEmployee(EmpDetails emp)
		{
			SqlConnection conn = new SqlConnection(connStr);
			SqlCommand cmd = conn.CreateCommand();
			cmd.CommandType = CommandType.StoredProcedure;
			cmd.CommandText = "procUpdateEmployee";

			cmd.Parameters.Add(new SqlParameter("@EmployeeId",SqlDbType.Int));
			cmd.Parameters["@EmployeeId"].Value = emp.EmployeeId;

			cmd.Parameters.Add(new SqlParameter("@FirstName",SqlDbType.NVarChar,20));
			cmd.Parameters["@FirstName"].Value = emp.FirstName;

			cmd.Parameters.Add(new SqlParameter("@LastName",SqlDbType.NVarChar,20));
			cmd.Parameters["@LastName"].Value = emp.LastName;

			try
			{
				conn.Open();
				int RecordsAffected = cmd.ExecuteNonQuery();				
				return RecordsAffected;				
			}
			catch(SqlException ex)
			{				
				throw new ApplicationException("Data Error");				
			}
			finally
			{
				conn.Close();				
			}
		}

		public int DeleteEmployee(int EmployeeId)
		{
			SqlConnection conn = new SqlConnection(connStr);
			SqlCommand cmd = conn.CreateCommand();
			cmd.CommandType = CommandType.StoredProcedure;
			cmd.CommandText = "procDeleteEmployee";

			cmd.Parameters.Add(new SqlParameter("@EmployeeId",SqlDbType.Int));
			cmd.Parameters["@EmployeeId"].Value = EmployeeId;

			try
			{
				conn.Open();
				int RecordsAffected = cmd.ExecuteNonQuery();
				conn.Close();
				return RecordsAffected;
			}
			catch(SqlException ex)
			{
				throw new ApplicationException("Data Error");
			}
			finally
			{
				conn.Close();
			}
		}

		public EmpDetails  GetEmployee(int EmployeeId)
		{			
			SqlConnection conn = new SqlConnection(connStr);
			SqlCommand cmd = conn.CreateCommand();
			cmd.CommandType = CommandType.StoredProcedure;			
			cmd.CommandText = "procGetEmployeeRec";

			cmd.Parameters.Add(new SqlParameter("@EmployeeId",SqlDbType.Int));
			cmd.Parameters["@EmployeeId"].Value = EmployeeId;

			try
			{
				conn.Open();
				SqlDataReader dr = cmd.ExecuteReader();
				EmpDetails emp;
				if(dr.Read())
					emp  = new EmpDetails((int)dr["EmployeeId"],(string)dr["FirstName"],(string)dr["LastName"]);
				else
					emp= null;
				dr.Close();
				conn.Close();
				return emp;
			}
			catch(SqlException ex)
			{
				throw new ApplicationException("Data Error\n" + ex.Message);
			}			
		}

		public EmpDetails[] GetAllEmployee()
		{			
			SqlConnection conn = new SqlConnection(connStr);
			SqlCommand cmd = conn.CreateCommand();
			cmd.CommandType = CommandType.StoredProcedure;			
			cmd.CommandText = "procGetAllEmployee";
			
			ArrayList arrEmp = new ArrayList();
			try
			{
				conn.Open();
				SqlDataReader dr = cmd.ExecuteReader();
				EmpDetails emp;
				if(dr.HasRows)
				{
					while(dr.Read())
					{
						emp  = new EmpDetails((int)dr["EmployeeId"],(string)dr["FirstName"],(string)dr["LastName"]);
						arrEmp.Add(emp);
					}
				}
				else
					emp= null;
				dr.Close();
				conn.Close();
				return (EmpDetails[])arrEmp.ToArray(typeof(EmpDetails));
			}
			catch(SqlException ex)
			{
				throw new ApplicationException("Data Error\n" + ex.Message);
			}			
		}

	}
}
